import { defineStore } from 'pinia';
import { api } from 'src/boot/axios';
import { AxiosResponse } from 'axios';
import { useMainStore } from 'src/store';

interface BalanceResponse {
  balance: number;
  credit: number;
  debit: number;
}

export interface BalancesResponse extends BalanceResponse {
  userid: string;
}

export interface TransactionsResponse {
  transactions: Array<FG.Transaction>;
  count?: number;
}

function fixTransaction(t: FG.Transaction) {
  t.time = new Date(t.time);
}

export const balanceStore = defineStore({
  id: 'balance',

  state: () => ({
    balances: [] as BalancesResponse[],
    shortcuts: [] as number[],
  }),

  getters: {
    balance() {
      const mainStore = useMainStore();
      return this.balances.find((v) => v.userid === mainStore.user?.userid);
    },
  },

  actions: {
    async createShortcut(shortcut: number) {
      const mainStore = useMainStore();
      const sc = [...this.shortcuts, shortcut];
      sc.sort();
      await api.put(`/users/${mainStore.currentUser.userid}/balance/shortcuts`, sc);
      this.shortcuts = sc;
    },

    async removeShortcut(shortcut: number) {
      const mainStore = useMainStore();
      const sc = this.shortcuts.filter((value: number) => value !== shortcut);
      await api.put(`/users/${mainStore.currentUser.userid}/balance/shortcuts`, sc);
      this.shortcuts = sc;
    },

    async getShortcuts(force = false) {
      if (force || this.shortcuts.length == 0) {
        const mainStore = useMainStore();
        const { data } = await api.get<number[]>(
          `/users/${mainStore.currentUser.userid}/balance/shortcuts`
        );
        this.shortcuts = data;
      }
    },
  },
});
